<?php

class WordPress_Form_Wizard_Entries extends WordPress_Form_Wizard
{
    protected $plugin_name;
    protected $version;
    protected $options;

    /**
     * Store Locator Plugin Construct
     * @author Daniel Barenkamp
     * @version 1.0.0
     * @since   1.0.0
     * @link    http://www.welaunch.io
     * @param   string                         $plugin_name
     * @param   string                         $version
     */
    public function __construct($plugin_name, $version)
    {
        $this->plugin_name = $plugin_name;
        $this->version = $version;

        $this->prefix = "wordpress_form_wizard_";
    }
    /**
     * Init the Public
     * @author Daniel Barenkamp
     * @version 1.0.0
     * @since   1.0.0
     * @link    http://www.welaunch.io
     * @return  boolean
     */
    public function init()
    {
        global $wordpress_form_wizard_options;

        $this->options = $wordpress_form_wizard_options;

        if (!$this->get_option('enable')) {
            return false;
        }

        add_action('admin_menu', array($this, 'add_menu'));

        return true;
    }

    /**
     * Init Reports Page in Admin
     * @author Daniel Barenkamp
     * @version 1.0.0
     * @since   1.0.0
     * @link    https://www.welaunch.io
     * @return  [type]                       [description]
     */
    public function add_menu()
    {        

        add_submenu_page(
            'edit.php?post_type=wizard_form',
            esc_html__('Entries', 'wordpress-form-wizard'),
            esc_html__('Entries', 'wordpress-form-wizard'),
            'manage_options',
            'wordpress-form-wizard-entries',
            array($this, 'get_page'),
            20
        );
    }

    public function get_page()
    {
    	global $wpdb;

    	$requestURI = esc_url($_SERVER['REQUEST_URI']);
		$dateForamt = get_option( 'date_format' );

      	?>

		<style>
		#wordpress-form-wizard-entries {
		    font-family: "Trebuchet MS", Arial, Helvetica, sans-serif;
		    border-collapse: collapse;
		    width: 100%;
		    margin-top:20px;
		}

		#wordpress-form-wizard-entries td, #wordpress-form-wizard-entries th {
		    border: 1px solid #ddd;
		    padding: 8px;
		    vertical-align: top;
		}

		#wordpress-form-wizard-entries tr:nth-child(even){background-color: #f2f2f2;}

		#wordpress-form-wizard-entries tr:hover {background-color: #ddd;}

		#wordpress-form-wizard-entries th {
		    padding-top: 12px;
		    padding-bottom: 12px;
		    text-align: left;
		    background-color: #072894;
		    color: #FFFFFF;
		}

		.tablenav {
			text-align: center;
		}
		.tablenav .tablenav-pages {
			float: none;
		}

		.wordpress-form-wizard-log-show:hover {
			cursor: pointer;
		}

		.wordpress-form-wizard-log {
			max-width: 350px;
			font-size: 11px;
			line-height: 16px;
			margin-top: 10px;
		}

		.wordpress-form-wizard-log-entry {
			width: 100%;
			display: block;
			padding: 5px;
			background-color: #333;
			color: #FFF;
		}

		.wordpress-form-wizard-log-entry:nth-child(even) {
			background-color: #000;
			color: #FFF;
		}

		</style>

		<h1><?php esc_html_e('Form Entries', 'wordpress-form-wizard') ?></h1>

		<table id="wordpress-form-wizard-entries">
			<thead>
				<tr>
					<th><?php echo esc_html__('Datetime', 'wordpress-form-wizard') ?></th>
					<th><?php echo esc_html__('Firstname', 'wordpress-form-wizard') ?></th>
					<th><?php echo esc_html__('Lastname', 'wordpress-form-wizard') ?></th>
					<th><?php echo esc_html__('Email', 'wordpress-form-wizard') ?></th>
					<th><?php echo esc_html__('Phone', 'wordpress-form-wizard') ?></th>
					<th><?php echo esc_html__('Company', 'wordpress-form-wizard') ?></th>
					<th><?php echo esc_html__('Address street', 'wordpress-form-wizard') ?></th>
					<th><?php echo esc_html__('Address zip', 'wordpress-form-wizard') ?></th>
					<th><?php echo esc_html__('Address city', 'wordpress-form-wizard') ?></th>
					<th><?php echo esc_html__('Address country', 'wordpress-form-wizard') ?></th>
					<th><?php echo esc_html__('Message', 'wordpress-form-wizard') ?></th>
					<th><?php echo esc_html__('Privacy', 'wordpress-form-wizard') ?></th>
					<th><?php echo esc_html__('Optional checkbox', 'wordpress-form-wizard') ?></th>
					<th><?php echo esc_html__('Price', 'wordpress-form-wizard') ?></th>
					<th><?php echo esc_html__('Choices_made', 'wordpress-form-wizard') ?></th>
					<th><?php echo esc_html__('Results', 'wordpress-form-wizard') ?></th>
					<th><?php echo esc_html__('Extra data', 'wordpress-form-wizard') ?></th>
					<th><?php echo esc_html__('Custom data', 'wordpress-form-wizard') ?></th>
				</tr>
			</thead>

			<?php

			$limit = 50;
			$paged = isset( $_GET['paged'] ) ? absint( $_GET['paged'] ) : 1;
			$offset = ( $paged - 1 ) * $limit;
				
			$table = $wpdb->prefix . 'form_wizard_entries';

			$entries = $wpdb->get_results("SELECT * FROM $table  ORDER BY `datetime` DESC LIMIT $limit OFFSET $offset");  
			// if(isset($_GET['search']) && !empty($_GET['search'])) {
			// 	$entriesQueryArgs['search'] = '*'.esc_attr( $_GET['search'] ).'*';
			// }
		   	$entriesTotal = count($entries);

		   	$pagesTotal = ceil($entriesTotal / $limit);

			if(empty($entries)) {
				echo esc_html__('No entries found', 'wordpress-form-wizard');
			} else {
		    	foreach ($entries as $entry) {

		    		$choices_made_text = "";
					if(isset($entry->choices_made) && !empty($entry->choices_made) ) {

						$choices_made = array_filter( unserialize( $entry->choices_made ) );
						if(!empty($choices_made)) {
							
							foreach($choices_made as $questionId => $answerIds) {

								$question = get_post($questionId);
								if(!$question) {
									continue;
								}

								$choices_made_text .= $question->post_title . ': ';
								if(!empty($answerIds)) {

									$questionType = get_post_meta($question->ID, $this->prefix . 'type', true);

									if($questionType == "slider" || $questionType == "textarea")  {
										$choices_made_text .= esc_html( $answerIds[0] );
									} else {
										foreach($answerIds as $answerId) {

											$answer = get_post($answerId);
											if(!$answer) {
												continue;
											}

											$choices_made_text .= $answer->post_title . ' ';
										}
									}
								}
								$choices_made_text .= '<br>';
							}
							
						}
					    $choices_made_text = apply_filters('wordpress_form_wizard_choices_made_text', $choices_made_text, $choices_made);
					}

					echo 
					'<tr>' .
						'<td>' . $entry->datetime . '</td>' .
						'<td>' . $entry->firstname . '</td>' .
						'<td>' . $entry->lastname . '</td>' .
						'<td>' . $entry->email . '</td>' .
						'<td>' . $entry->phone . '</td>' .
						'<td>' . $entry->company . '</td>' .
						'<td>' . $entry->address_street . '</td>' .
						'<td>' . $entry->address_zip . '</td>' .
						'<td>' . $entry->address_city . '</td>' .
						'<td>' . $entry->address_country . '</td>' .
						'<td>' . $entry->message . '</td>' .
						'<td>' . $entry->privacy . '</td>' .
						'<td>' . $entry->optional_checkbox . '</td>' .
						'<td>' . $entry->price . '</td>' .
						'<td>' . $choices_made_text . '</td>' .
						'<td>' . implode(', ', explode(',', $entry->post_ids) ) . '</td>' .
						'<td>' . $entry->extra_data . '</td>' .
						'<td>' . $entry->custom_data . '</td>' .
					'</tr>';
		    	}
	    	}
	    	?>
		</table>
		<script>
			jQuery('.wordpress-form-wizard-log-show').on('click', function(e) {
				jQuery(this).next('.wordpress-form-wizard-log').toggle();
			});
		</script>
    	<?php

		$page_links = paginate_links( array(
		    'base' => add_query_arg( 'paged', '%#%' ),
		    'total' => $pagesTotal,
		    'current' => $paged
		) );

		if ( $page_links ) {
		    echo '<div class="tablenav"><div class="tablenav-pages" style="margin: 1em 0">' . $page_links . '</div></div>';
		}
    }	
}