<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://welaunch.io/plugins/wordpress-form-wizard/
 * @since      1.0.0
 *
 * @package    WordPress_Form_Wizard_Public
 * @subpackage WordPress_Form_Wizard
 */
class WordPress_Form_Wizard_Mailer extends WordPress_Form_Wizard {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	protected $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of this plugin.
	 */
	protected $version;

	/**
	 * options of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      array    $options
	 */
	protected $options;


	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
    public function __construct($plugin_name, $version)
    {
        $this->plugin_name = $plugin_name;
        $this->version = $version;
		
		$this->prefix = "wordpress_form_wizard_";
	}

	public function init()
	{
		global $wordpress_form_wizard_options;
		$this->options = $wordpress_form_wizard_options;


	}

    public function send_email()
    {
		$response = array(
			'status' => 0,
			'message' => '',
		);

        if (!defined('DOING_AJAX') || !DOING_AJAX) {
        	$response['message'] = esc_html__('No AJAX call', 'wordpress-form-wizard');
        	echo json_encode($response);
            die();
        }

        if (!isset($_POST['form_id']) || empty($_POST['form_id'])) {
            $response['message'] = esc_html__('Form id missing.', 'wordpress-form-wizard');
            echo json_encode($response);
            die();
        }

        if (!isset($_POST['choices_made']) || empty($_POST['choices_made'])) {
            $response['message'] = esc_html__('No choices made.', 'wordpress-form-wizard');
            echo json_encode($response);
            die();
        }

        $form_id = (int) $_POST['form_id'];
        $form = get_post($form_id);
        if(!$form) {
            $response['message'] = esc_html__('Form not found.', 'wordpress-form-wizard');
            echo json_encode($response);
            die();
        }

        $formMeta = get_post_meta($form_id);

		if($this->get_option('emailShowName')) {

			if($this->get_option('emailShowNameRequired') && ( !isset($_POST[$this->prefix . 'firstname']) || empty($_POST[$this->prefix . 'firstname'])) ) {
	            $response['message'] = sprintf( esc_html__('%s missing.', 'wordpress-form-wizard'), $this->get_option('textsFirstname') );
	            echo json_encode($response);
	            die();
			}

			if($this->get_option('emailShowNameRequired') && ( !isset($_POST[$this->prefix . 'lastname']) || empty($_POST[$this->prefix . 'lastname'])) ) {
	            $response['message'] = sprintf( esc_html__('%s missing.', 'wordpress-form-wizard'), $this->get_option('textsLastname') );
	            echo json_encode($response);
	            die();
			}
		}

		$to = "";
		if($this->get_option('emailShowEmail')) {

			if($this->get_option('emailShowEmailRequired') && ( !isset($_POST[$this->prefix . 'email']) || empty($_POST[$this->prefix . 'email'])) ) {
	            $response['message'] = sprintf( esc_html__('%s missing.', 'wordpress-form-wizard'), $this->get_option('textsEmail') );
	            echo json_encode($response);
	            die();
			}

			$to = esc_html( $_POST[$this->prefix . 'email']);

		}

		if($this->get_option('emailShowPhone')) {

			if($this->get_option('emailShowPhoneRequired') && ( !isset($_POST[$this->prefix . 'phone']) || empty($_POST[$this->prefix . 'phone'])) ) {
	            $response['message'] = sprintf( esc_html__('%s missing.', 'wordpress-form-wizard'), $this->get_option('textsPhone') );
	            echo json_encode($response);
	            die();
			}

		}

		if($this->get_option('emailShowAddress')) {

			if($this->get_option('emailShowAddressRequired') && ( !isset($_POST[$this->prefix . 'address_street']) || empty($_POST[$this->prefix . 'address_street'])) ) {
	            $response['message'] = sprintf( esc_html__('%s missing.', 'wordpress-form-wizard'), $this->get_option('textsAddressStreet') );
	            echo json_encode($response);
	            die();
			}

			if($this->get_option('emailShowAddressRequired') && ( !isset($_POST[$this->prefix . 'address_zip']) || empty($_POST[$this->prefix . 'address_zip'])) ) {
	            $response['message'] = sprintf( esc_html__('%s missing.', 'wordpress-form-wizard'), $this->get_option('textsAddressZIP') );
	            echo json_encode($response);
	            die();
			}

			if($this->get_option('emailShowAddressRequired') && ( !isset($_POST[$this->prefix . 'address_city']) || empty($_POST[$this->prefix . 'address_city'])) ) {
	            $response['message'] = sprintf( esc_html__('%s missing.', 'wordpress-form-wizard'), $this->get_option('textsAddressCity') );
	            echo json_encode($response);
	            die();
			}

			if($this->get_option('emailShowAddressRequired') && ( !isset($_POST[$this->prefix . 'address_country']) || empty($_POST[$this->prefix . 'address_country'])) ) {
	            $response['message'] = sprintf( esc_html__('%s missing.', 'wordpress-form-wizard'), $this->get_option('textsAddressCountry') );
	            echo json_encode($response);
	            die();
			}

		}

		if($this->get_option('emailShowMessage')) {

			if($this->get_option('emailShowMessageRequired') && ( !isset($_POST[$this->prefix . 'message']) || empty($_POST[$this->prefix . 'message'])) ) {
	            $response['message'] = sprintf( esc_html__('%s missing.', 'wordpress-form-wizard'), $this->get_option('textsMessage') );
	            echo json_encode($response);
	            die();
			}
		}

		if(!isset($_POST[$this->prefix . 'privacy']) || empty($_POST[$this->prefix . 'privacy'])) {
            $response['message'] = sprintf( esc_html__('%s missing.', 'wordpress-form-wizard'), $this->get_option('textsPrivacy') );
            echo json_encode($response);
            die();
		}

		$emailSubject = $this->get_option('emailSubject');
		$emailText = $this->get_option('emailText');
		$emailButtonText = $this->get_option('emailButtonText');
		$emailButtonURL = $this->get_option('emailButtonURL');
		$emailFromName = $this->get_option('emailFromName');
		$emailLogo = $this->get_option('emailLogo');
		$emailLogoURL = isset($emailLogo['url']) ? $emailLogo['url'] : '';

		$emailReplyTo = $this->get_option('emailReplyTo');
		$emailFooter = $this->get_option('emailFooter');

        $emailText = wpautop($emailText);

        $headers = array(
            'Content-Type: text/html; charset=UTF-8',
            'Reply-To:' . $emailFromName. ' <' . $emailReplyTo . '>',
            'From:' . $emailFromName. ' <' . $emailReplyTo . '>',
        );
        
        $cc = $this->get_option('emailCC');
        if(!empty($cc)) {
        	$headers[] = 'Cc: ' . $cc;
        	if(empty($to)) {
        		$to = $cc;
        	}
        }

        $bcc = $this->get_option('emailBCC');
        if(!empty($bcc)) {
        	$headers[] = 'Bcc: ' . $bcc;
        }

		$tpl = $this->get_option('emailTemplate');
		$emailSentText = $this->get_option('emailSentText');

		$tpl = str_replace(
			array(
				'{{fromName}}',
				'{{buttonURL}}',
				'{{buttonText}}',
				'{{text}}',
				'{{subject}}',
				'{{logo}}',
				'{{footer}}',
			),
			array(
				$emailFromName,
				$emailButtonURL,
				$emailButtonText,
				$emailText,
				$emailSubject,
				$emailLogoURL,
				$footer,
			),
			$tpl
		);

		$emailSentText = str_replace(
			array(
				'{{fromName}}',
				'{{buttonURL}}',
				'{{buttonText}}',
				'{{text}}',
				'{{subject}}',
				'{{logo}}',
				'{{footer}}',
				'{{formTitle}}',
			),
			array(
				$emailFromName,
				$emailButtonURL,
				$emailButtonText,
				$emailText,
				$emailSubject,
				$emailLogoURL,
				$footer,
				$form->post_title,
			),
			$emailSentText
		);

        $dataToSave = array();
        foreach($_POST as $postKey => $postValue) {

        	if(!str_contains($postKey, $this->prefix)) {
        		continue;
        	}

			$postKey = substr( $postKey, 22 );

        	$postValue = esc_html( $postValue );
        	$tpl = str_replace('{{' . $postKey . '}}', $postValue, $tpl);
        	$emailSubject = str_replace('{{' . $postKey . '}}', $postValue, $emailSubject);
        	$emailSentText = str_replace('{{' . $postKey . '}}', $postValue, $emailSentText);
        	$dataToSave[$postKey] = $postValue;
        }

        $resultData = "";
		if(isset($_POST['wordpress_form_wizard_post_ids'])) {

			$resultPostIds = array_filter( explode(',', $_POST['wordpress_form_wizard_post_ids']), 'is_numeric');
			if(!empty($resultPostIds)) {
				$resultData = '<table><tr>';

				$i = 0;
				foreach($resultPostIds as $resultPostId) {

					if ($i % 3 === 0) {
					    $resultData .= "</tr>\n<tr>";
					}

					$resultPost = get_post($resultPostId);
					if($resultPost) {

						$link = get_permalink($resultPostId);
						$img = wp_get_attachment_image_src( get_post_thumbnail_id( $resultPostId ), $this->get_option('imageSize') );
						$imgSrc =  (isset($img[0]) && !empty($img[0])) ?  $img[0] : plugin_dir_url( dirname( __FILE__ ) ) . 'assets/img/placeholder.png';

						$resultData .= 
						'<td>
							<a href="' . $link . '"><img class="wordpress-form-wizard-responsive-image" src="' . $imgSrc . '" /></a>
							' . $resultPost->post_title . '
						</td>';
					}

					$i++;

				}
				$resultData .= '</tr></table>';
			}

        	$tpl = str_replace('{{results}}', $resultData, $tpl);
        	$emailSubject = str_replace('{{results}}', $resultData, $emailSubject);
        	$emailSentText = str_replace('{{results}}', $resultData, $emailSentText);
		}

        $emailSubject = str_replace('{{formTitle}}', $form->post_title, $emailSubject);
        $tpl = str_replace('{{formTitle}}', $form->post_title, $tpl);

        $choices_made_text = "";
        $choices_made = array();
        if(isset($_POST['choices_made']) && is_array($_POST['choices_made']) ) {

        	$choices_made_text = "<ul>";
        	$choices_made = array_filter( $_POST['choices_made'] );
        	if(!empty($choices_made)) {
        		
        		foreach($choices_made as $questionId => $answerIds) {

        			$question = get_post($questionId);
        			if(!$question) {
        				continue;
        			}

					$choices_made_text .= '<li>' . $question->post_title . ': ';
					if(!empty($answerIds)) {

						$questionType = get_post_meta($question->ID, $this->prefix . 'type', true);

						if($questionType == "slider" || $questionType == "textarea")  {
							$choices_made_text .= esc_html( $answerIds[0] );
						} else {
							foreach($answerIds as $answerId) {

								$answer = get_post($answerId);
								if(!$answer) {
									continue;
								}

								$choices_made_text .= $answer->post_title . ' ';
							}
						}
					}
					$choices_made_text .= '</li>';
        		}
        		
        	}
	        $choices_made_text .= '</ul>';
	        $choices_made_text = apply_filters('wordpress_form_wizard_choices_made_text', $choices_made_text, $choices_made);
        }
        $dataToSave['choices_made'] = serialize($choices_made);

        $tpl = str_replace('{{choices_made}}', $choices_made_text, $tpl);
        $emailSentText = str_replace('{{choices_made}}', $choices_made_text, $emailSentText);
        
        if (wp_mail($to, $emailSubject, $tpl, $headers)) {
        	$response['status'] = 1;
			$response['message'] = '<div class="wordpress-form-wizard-message-sent">' . wpautop( $emailSentText ) . '</div>';
        } else {
           $response['message'] = esc_html__('Email not sent.', 'wordpress-form-wizard'); 
        }

	   	global $wpdb;

	   	unset($dataToSave['submit']);

	   	$db_name = $wpdb->prefix . 'form_wizard_entries';
	   	$wpdb->insert($db_name, $dataToSave, array( '%s', '%s'));

	   	if($this->get_option('debugMode')) {
	        echo $wpdb->last_query;
	        echo $wpdb->last_result;
	        echo $wpdb->last_error;
        }

        do_action('wordpress_form_wizard_email', $response, $choices_made, $dataToSave);

        echo json_encode($response);
        die();
    }
}